@@ -26,8 +26,8 @@ ExampleAssistant::ExampleAssistant()
   set_title("Gtk::Assistant example");
   set_default_size(400, 300);
 
-  m_box.add(m_label1);
-  m_box.add(m_entry);
+  m_box.append(m_label1);
+  m_box.append(m_entry);
   m_label1.set_expand();
   m_entry.set_expand();
 
