@@ -25,11 +25,11 @@ ExampleAppPrefs::ExampleAppPrefs(BaseObjectType* cobject,
   m_font(nullptr),
   m_transition(nullptr)
 {
-  m_refBuilder->get_widget("font", m_font);
+  m_font = m_refBuilder->get_widget<Gtk::FontButton>("font");
   if (!m_font)
     throw std::runtime_error("No \"font\" object in prefs.ui");
 
-  m_refBuilder->get_widget("transition", m_transition);
+  m_transition = m_refBuilder->get_widget<Gtk::ComboBoxText>("transition");
   if (!m_transition)
     throw std::runtime_error("No \"transition\" object in prefs.ui");
 
@@ -44,8 +44,7 @@ ExampleAppPrefs* ExampleAppPrefs::create(Gtk::Window& parent)
   // Load the Builder file and instantiate its widgets.
   auto refBuilder = Gtk::Builder::create_from_resource("/org/gtkmm/exampleapp/prefs.ui");
 
-  ExampleAppPrefs* dialog = nullptr;
-  Gtk::Builder::get_widget_derived(refBuilder, "prefs_dialog", dialog);
+  auto dialog = Gtk::Builder::get_widget_derived<ExampleAppPrefs>(refBuilder, "prefs_dialog");
   if (!dialog)
     throw std::runtime_error("No \"prefs_dialog\" object in prefs.ui");
 
