@@ -26,15 +26,15 @@ ExampleWindow::ExampleWindow()
 {
   set_title("Gtk::AboutDialog example");
 
-  add(m_VBox);
+  set_child(m_VBox);
 
-  m_VBox.add(m_Label);
+  m_VBox.append(m_Label);
   m_Label.set_expand(true);
   m_Label.set_wrap(true);
   m_Label.set_selectable(true);
 
-  m_VBox.add(m_ButtonBox);
-  m_ButtonBox.add(m_Button);
+  m_VBox.append(m_ButtonBox);
+  m_ButtonBox.append(m_Button);
   m_Button.set_expand(true);
   m_Button.set_halign(Gtk::Align::CENTER);
   m_Button.set_valign(Gtk::Align::CENTER);
@@ -42,6 +42,7 @@ ExampleWindow::ExampleWindow()
               &ExampleWindow::on_button_clicked) );
 
   m_Dialog.set_transient_for(*this);
+  m_Dialog.set_hide_on_close();
 
   m_Dialog.set_logo(Gdk::Texture::create_for_pixbuf(
     Gdk::Pixbuf::create_from_resource("/about/gtkmm_logo.gif", -1, 40, true)));
@@ -60,9 +61,6 @@ ExampleWindow::ExampleWindow()
   list_authors.push_back("AN Other");
   m_Dialog.set_authors(list_authors);
 
-  m_Dialog.signal_response().connect(
-    sigc::mem_fun(*this, &ExampleWindow::on_about_dialog_response) );
-
   m_Button.grab_focus();
 }
 
@@ -70,27 +68,6 @@ ExampleWindow::~ExampleWindow()
 {
 }
 
-void ExampleWindow::on_about_dialog_response(int response_id)
-{
-  std::cout << response_id
-    << ", close=" << Gtk::ResponseType::CLOSE
-    << ", cancel=" << Gtk::ResponseType::CANCEL
-    << ", delete_event=" << Gtk::ResponseType::DELETE_EVENT
-    << std::endl;
-
-  switch (response_id)
-  {
-  case Gtk::ResponseType::CLOSE:
-  case Gtk::ResponseType::CANCEL:
-  case Gtk::ResponseType::DELETE_EVENT:
-    m_Dialog.hide();
-    break;
-  default:
-    std::cout << "Unexpected response!" << std::endl;
-    break;
-  }
-}
-
 void ExampleWindow::on_button_clicked()
 {
   m_Dialog.show();
