@@ -18,6 +18,7 @@
 #define GTKMM_EXAMPLEWINDOW_H
 
 #include <gtkmm.h>
+#include <memory>
 
 class ExampleWindow : public Gtk::Window
 {
@@ -29,10 +30,13 @@ protected:
   //Signal handlers:
   void on_button_info_clicked();
   void on_button_question_clicked();
+  void on_question_dialog_response(int response_id);
 
   //Child widgets:
   Gtk::Box m_ButtonBox;
   Gtk::Button m_Button_Info, m_Button_Question;
+
+  std::unique_ptr<Gtk::MessageDialog> m_pDialog;
 };
 
 #endif //GTKMM_EXAMPLEWINDOW_H
