@@ -17,15 +17,22 @@
 #include "examplewindow.h"
 #include <gtkmm/dialog.h>
 
-
 ExampleWindow::ExampleWindow()
-: m_Button("Show Dialog")
+: m_Button("Show Dialog"),
+  m_Dialog("The Dialog")
 {
   set_title("Gtk::Dialog example");
 
-  add(m_Button);
+  set_child(m_Button);
   m_Button.signal_clicked().connect(sigc::mem_fun(*this,
               &ExampleWindow::on_button_clicked) );
+
+  m_Dialog.set_default_size(150, 100);
+  m_Dialog.set_transient_for(*this);
+  m_Dialog.set_modal();
+  m_Dialog.set_hide_on_close();
+  m_Dialog.signal_response().connect(
+    sigc::hide(sigc::mem_fun(m_Dialog, &Gtk::Widget::hide)));
 }
 
 ExampleWindow::~ExampleWindow()
@@ -34,7 +41,5 @@ ExampleWindow::~ExampleWindow()
 
 void ExampleWindow::on_button_clicked()
 {
-  Gtk::Dialog dialog;
-  dialog.set_default_size(100,100);
-  dialog.run();
+  m_Dialog.show();
 }
