@@ -36,11 +36,11 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   set_title(app_title);
   set_default_size(400, 300);
 
-  add(m_VBox);
+  set_child(m_VBox);
 
   build_main_menu(app);
 
-  m_VBox.add(m_Grid);
+  m_VBox.append(m_Grid);
 
   //Arrange the widgets inside the grid:
   m_Grid.set_expand(true);
@@ -53,7 +53,7 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   m_Grid.attach(m_SurnameEntry, 1, 1);
 
   //Add the TextView, inside a ScrolledWindow:
-  m_ScrolledWindow.add(m_TextView);
+  m_ScrolledWindow.set_child(m_TextView);
 
   //Only show the scrollbars when they are necessary:
   m_ScrolledWindow.set_policy(Gtk::PolicyType::AUTOMATIC, Gtk::PolicyType::AUTOMATIC);
@@ -66,7 +66,7 @@ ExampleWindow::ExampleWindow(const Glib::RefPtr<Gtk::Application>& app)
   m_TextView.set_buffer(m_refTextBuffer);
 
   m_Statusbar.set_expand(true);
-  m_VBox.add(m_Statusbar);
+  m_VBox.append(m_Statusbar);
 }
 
 ExampleWindow::~ExampleWindow()
@@ -155,44 +155,45 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
   Glib::ustring ui_toolbar_info =
     "<!-- Generated with glade 3.18.3 and then changed manually -->"
     "<interface>"
-      "<requires lib='gtk' version='3.94'/>"
-      "<object class='GtkToolbar' id='toolbar'>"
+      "<requires lib='gtk' version='3.98'/>"
+      "<object class='GtkBox' id='toolbar'>"
         "<property name='can_focus'>False</property>"
+        "<property name='spacing'>3</property>"
         "<child>"
-          "<object class='GtkToolButton' id='toolbutton_new'>"
+          "<object class='GtkButton' id='toolbutton_new'>"
             "<property name='can_focus'>False</property>"
             "<property name='tooltip_text' translatable='yes'>New</property>"
             "<property name='action_name'>example.new</property>"
             "<property name='icon_name'>document-new</property>"
-            "<property name='expand'>False</property>"
-            "<property name='homogeneous'>True</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
         "<child>"
-          "<object class='GtkToolButton' id='toolbutton_print'>"
+          "<object class='GtkButton' id='toolbutton_print'>"
             "<property name='can_focus'>False</property>"
             "<property name='tooltip_text' translatable='yes'>Print</property>"
             "<property name='action_name'>example.print</property>"
             "<property name='icon_name'>document-print</property>"
-            "<property name='expand'>False</property>"
-            "<property name='homogeneous'>True</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
         "<child>"
-          "<object class='GtkSeparatorToolItem' id='separator1'>"
+          "<object class='GtkSeparator' id='separator1'>"
             "<property name='can_focus'>False</property>"
-            "<property name='expand'>False</property>"
-            "<property name='homogeneous'>False</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
         "<child>"
-          "<object class='GtkToolButton' id='toolbutton_quit'>"
+          "<object class='GtkButton' id='toolbutton_quit'>"
             "<property name='can_focus'>False</property>"
             "<property name='tooltip_text' translatable='yes'>Quit</property>"
             "<property name='action_name'>example.quit</property>"
             "<property name='icon_name'>application-exit</property>"
-            "<property name='expand'>False</property>"
-            "<property name='homogeneous'>True</property>"
+            "<property name='hexpand'>False</property>"
+            "<property name='vexpand'>False</property>"
           "</object>"
         "</child>"
       "</object>"
@@ -214,19 +215,18 @@ void ExampleWindow::build_main_menu(const Glib::RefPtr<Gtk::Application>& app)
     g_warning("GMenu not found");
   else
   {
-    auto pMenuBar = Gtk::make_managed<Gtk::MenuBar>(gmenu);
+    auto pMenuBar = Gtk::make_managed<Gtk::PopoverMenuBar>(gmenu);
 
-    // Add the MenuBar to the window:
-    m_VBox.add(*pMenuBar);
+    // Add the PopoverMenuBar to the window:
+    m_VBox.append(*pMenuBar);
   }
 
   // Get the toolbar and add it to a container widget:
-  Gtk::Toolbar* toolbar = nullptr;
-  m_refBuilder->get_widget("toolbar", toolbar);
+  auto toolbar = m_refBuilder->get_widget<Gtk::Box>("toolbar");
   if (!toolbar)
-    g_warning("GtkToolbar not found");
+    g_warning("toolbar not found");
   else
-    m_VBox.add(*toolbar);
+    m_VBox.append(*toolbar);
 }
 
 void ExampleWindow::on_printoperation_status_changed()
@@ -252,9 +252,16 @@ void ExampleWindow::on_printoperation_done(Gtk::PrintOperation::Result result)
 
   if (result == Gtk::PrintOperation::Result::ERROR)
   {
-    Gtk::MessageDialog err_dialog(*this, "Error printing form", false,
-            Gtk::MessageType::ERROR, Gtk::ButtonsType::OK, true);
-    err_dialog.run();
+    if (!m_pDialog)
+    {
+      m_pDialog.reset(new Gtk::MessageDialog(*this, "Error printing form",
+        false /* use_markup */, Gtk::MessageType::ERROR, Gtk::ButtonsType::OK,
+        true /* modal */));
+      m_pDialog->set_hide_on_close(true);
+      m_pDialog->signal_response().connect(
+        sigc::hide(sigc::mem_fun(*m_pDialog, &Gtk::Widget::hide)));
+    }
+    m_pDialog->show();
   }
   else if (result == Gtk::PrintOperation::Result::APPLY)
   {
